% Chapt11Fig13
% this program calculates and plots the atomic orbits according to the
% hydrogen atomic wave functions
% there are three parameters n,l and m, it must satisfy n>l>=m

clear all; 
clf;
n=input('Input quantum number n = ');
l=input('Input quantum number l (n>l>=0) = ');
m=input('Input quantum number m (l>=|m|) = ');

if ((abs(m) > l)|(l>n))                 %check if n>l>=m
    err='Wrong input parameter value!'
    return;
end

npoints = 101;      %
rslv = 401;         % the angle resulution for 3D drawing, it is 2*pi/(rslv-1)

%a0 = 0.529177e-8;    %Bohr radius
Z = 1;			%value ion core of charge, Z=1 for H, Z=2 for He+, etc.


%***********************************************
% to draw the curve of |Rnl(r)|^2 and |Rnl(r)|
% we scan from r/a0 = 0 to 30, then select r=2a0
% to draw the Hydrogen Orbitals
%==============================================
% Calculate the Laguerre Polynomial value L in function
% LaguerreTony: the correponding symbols are: 
%           L:Laguerre Polynomial L
%           ro: the parameter ro in L
%           n: the parameter n in L
%           k: the parameter k in L
%==============================================
for i=1:npoints
    r(i)=(i-1)*30/npoints;
    %r(i)=(n^1.6)*(i-1)/15.0;						%scale r with n^1.6/15
    ro(i) = r(i)*2*Z/n;
    L(i) = Laguerre(n,l,ro(i));
    const=-((2*Z)/n)^(3/2);
    const=const*(((factorial(n-l-1))/(2*n*((factorial(n+l))^3)))^0.5);
    %const=-(((2*Z)^3*(n^-3)*((factorial(n-l-1))/(2*n*((factorial(n+l))^3)))^.5);
    Rnl(i)=const*(exp(-ro(i)/2))*(ro(i)^l)*L(i);
    %Rnl2(i)=4*pi*(r(i)^2)*(Rnl(i)^2);
    Rnl2(i)=(r(i)^2)*(Rnl(i)^2);
end

figure(1);
subplot(2,1,1);
plot(r,Rnl,'r');
%xlabel('Distance, r/a_B');
xlabel('Position, r/a_B');ylabel('R_{nl} wave function');
ttl2=['R_{nl} n=',num2str(n),', l=',num2str(l),', m=',num2str(Z)];
title(ttl2);
subplot(2,1,2);
plot(r,Rnl2,'r');
xlabel('Position, r/a_B');ylabel('|R_{nl}|^2 wave function squared');
ttl3=['4\pi r^2 dr |R_{nl}|^2 n=',num2str(n),', l=',num2str(l),...
    ', m=',num2str(Z)];
title(ttl3);
%====================================================
% multiply the Rnl with the spherical_harmonics to generate
% electron density, 3 figures are drawn in the code below,
% figure(2) is the modulus square of the atomic orbital shape
% figure(3) and (4) correspond to the real and imaginary
% part of the atomic orbitals
%=====================================================
t=(npoints-1)/2;    % make sure the radius is not zero
if Rnl(t)==0        % if the selected Rnl(1) is zero
    t=t+1;          % use Rnl(2)
end

U = linspace(0, 2*pi, rslv);  % Phi in the spherical coordinates
V = linspace(0, 2*pi, rslv);  % Theta in the spherical coordinates
[u,v] = meshgrid(U,V);
%=====================================================
factor1=factorial(l-m);
factor2=factorial(l+m);
a=(2*l+1)*factor1/(4*pi*factor2);
a=a*abs(Rnl(t));

pp=legendre(l,cos(v));

if (l == 0)
    gs = a.*pp;
else
    plm=pp(abs(m)+1,:);
    tt=1;
    for k1=1:rslv
        for k2=1:rslv
            gs(k2,k1) = a*plm(tt)^2;
            tt=tt+1;
        end;
    end
end
gsr = (gs.^0.5).*cos(m*u);
gsi = (gs.^0.5).*sin(m*u);
%======================================================
% Spherical
X=cos(u).*sin(v).*gs;
Y=sin(u).*sin(v).*gs;
Z=cos(v).*gs;
% the code lines below try to figure out the maximim
% coordinates value and the put it as the range of all
% three coordinates X, Y and Z when drawing the figure
% the same code is repeated in drawing the real and
% imaginary part figures
xmax = 0;
ymax = 0;
zmax = 0;
tmp=max(X,[],1);
xmax=max(tmp);

tmp=max(Y,[],1);
ymax=max(tmp);

tmp=max(Z,[],1);
zmax=max(tmp);

amax = max([xmax ymax zmax]);
amaxn= amax*(-1.0);
%=================================
figure(2);
surf(X,Y,Z,'FaceColor','m','EdgeColor','none')
xlabel('X');ylabel('Y');zlabel('Z');
camlight left; lighting phong;axis equal;
ttl=['Hydrogen atom |\Psi(',num2str(n),num2str(l),num2str(m),')|^2'];
title(ttl);
axis([amaxn amax amaxn amax amaxn amax]);
if (m == 0)
    return;
end
%====================================================
% the code lines below draw the real part and the imaginary
% part of the spherical orbits of the atom, if you don't
% want to draw them, just return from here, otherwise it
% will go on.
%return;
%=====================================================
% Real Part
Xr=cos(u).*sin(v).*gsr;
Yr=sin(u).*sin(v).*gsr;
Zr=cos(v).*gsr;

xrmax = 0;
yrmax = 0;
zrmax = 0;
tmp=max(Xr,[],1);
xrmax=max(tmp);

tmp=max(Yr,[],1);
yrmax=max(tmp);

tmp=max(Zr,[],1);
zrmax=max(tmp);

armax = max([xrmax yrmax zrmax]);
armaxn= armax*(-1.0);

figure(3);
surf(Xr,Yr,Zr,'FaceColor','m','EdgeColor','none')
xlabel('X');ylabel('Y');zlabel('Z');
camlight left; lighting phong;axis equal;
ttl2=['Real Part, n=',num2str(n),', l=',num2str(l),', m=',num2str(m)];
title(ttl2);
axis([armaxn armax armaxn armax armaxn armax]);
%=====================================================
% imaginary part
Xi=cos(u).*sin(v).*gsi;
Yi=sin(u).*sin(v).*gsi;
Zi=cos(v).*gsi;

ximax = 0;
yimax = 0;
zimax = 0;
tmp=max(Xi,[],1);
ximax=max(tmp);

tmp=max(Yi,[],1);
yimax=max(tmp);

tmp=max(Zi,[],1);
zimax=max(tmp);

aimax = max([ximax yimax zimax]);
aimaxn= aimax*(-1.0);

figure(4);
surf(Xi,Yi,Zi,'FaceColor','m','EdgeColor','none')
xlabel('X');
ylabel('Y');
zlabel('Z');
camlight left; lighting phong;axis equal;
ttl3=['Imaginary Part n=',num2str(n),', l=',num2str(l),', m=',num2str(m)];
title(ttl3);
axis([aimaxn aimax aimaxn aimax aimaxn aimax]);
