% Chapt9Exercise2.m
% Plot peak gain as function of carrier density from ncarrier1 to ncarrier2
% uses function mu.m and fermi.m
% carrier density n(m-3), temperature kelvin(K)
% 
clear
clf   
   echarge=1.60219e-19;				%Electron charge [C]
   hbar=1.0545928e-34;				%Planck's constant [J s]
   c = 2.997925e8;					%Speed of light in vacuum [m s-1]
   kB=8.617e-5;						%Boltzmann constant [eV K-1]
   epsilon0=8.85419e-12;			%Permittivity of free space [F m-1]
 
   m0=9.10956e-31;					%Bare electron mass [kg]
   me=0.07*m0;						%Effective electron mass [kg]
   mhh=0.5*m0;						%Effective hhole mass [kg]
   mr=1/(1/me+1/mhh);				%Reduced electron mass
   rerr=1e-3;						%Relative error
   
   nr=3.3;							%Refractive index
   Eg=1.4;							%Band gap energy [eV]

	n1=1e18;						%Minimum carrier density [cm-3]
   ncarrier1=n1*1e6;				%Convert carrier density to [m-3]
   n2=1e19;							%Maximum carrier density [cm-3]
   ncarrier2=n2*1e6;				%Convert carrier density to [m-3]

   kelvin=300.0;					%Temperature [K]
   kBT=kB*kelvin;					%Thermal energy [eV]
   beta=1/kBT;						%Inverse thermal energy [eV-1]
   
   %const=-echarge^2*hbar/(2*nr*c*m0^2*epsilon0)*((2*mr/hbar^2)^1.5)
   const=2.64e4;%put in constant that gives gain ~ 330 cm-1 gain at 2e18 cm-3
   

   deltacarrier=(ncarrier2-ncarrier1)/100;
   for k=1:100
      ncarrier(k)=ncarrier1+(k-1)*deltacarrier;
      
   muhh(k)=mu(mhh,ncarrier(k),kelvin,rerr);	%Call mu chemical potential function for holes
   mue(k) =mu(me, ncarrier(k),kelvin,rerr); %Call mu chemical potential function for electrons
   deltamu(k)=mue(k)+muhh(k);				%Delta mu
   
      deltae=0.001;							%1meV energy step
      rspon=0;
      peakgain(k)=-10000;
      rspontotal(k)=0;
   	for j=1:500
      	Energy(j)=j*deltae;                 %Photon energy
      	Ehh=Energy(j)/(1+mhh/me);			%Energy in hole band
      	Ee=Energy(j)/(1+me/mhh);			%Energy in conduction band
      	fhh=fermi(beta,Ehh,muhh(k));		%Call Fermi function for holes
      	fe=fermi(beta,Ee,mue(k));			%Call Fermi function for electrons
         gain(j)=const*(Energy(j)^0.5)*(fhh+fe-1);
         rspon=rspon+(const*(Energy(j)^0.5))*(fe*fhh)*deltae;
         if(gain(j) > peakgain(k))
            peakgain(k)=gain(j);
         end
         
      end
      rspontotal(k)=rspon;
   end
   
   figure(1)
   plot(ncarrier./1e6, deltamu);
   xlabel('Carrier concentration, n (cm^{-3})');
   ylabel('Difference in chemical potential,   \Delta\mu (eV)');
   title(['T = ',num2str(kelvin),' K,  m_e = ',num2str(me/m0),...
       ', m_{hh} = ',num2str(mhh/m0),' ']);
   grid on;
   
   figure(2)
   plot(ncarrier./1e6, peakgain);
   xlabel('Carrier concentration, n (cm^{-3})');
   ylabel('Peak optical gain, g (cm^{-1})');
   title(['T = ',num2str(kelvin),' K,  m_e = ',num2str(me/m0),...
       ', m_{hh} = ',num2str(mhh/m0),' ']);
   grid on;
   
   figure(3)
   plot(ncarrier./1e6, rspontotal);
   xlabel('Carrier concentration, n (cm^{-3})');
   ylabel('Total spontaneous emission, rsptotal (arb.)');
   title(['T = ',num2str(kelvin),' K,  m_e = ',num2str(me/m0),...
       ', m_{hh} = ',num2str(mhh/m0),' ']);
   grid on;
   
   
   
   