function [e,phi]=solve_schMperiodic(length,n,v,mass,start_num_sol,end_num_sol)
% Solve Schrodinger equation for energy eigenvalues and eigenfunctions.
% [energy, phi_fun]=solve_sch(length,number,potential,mass,start_num_sol,end_num_sol)
% solves time-independent Schrodinger eqution in region 0<=x<=length with
% periodic boundary conditions.
%
% length		length of region (nm)
% n				number of sample points 
% v				potential inside region (eV)
% mass			effective electron mass
% sol_num		number of solutions sought
% e				energy eigenvalue (eV)
% phi			eigenfunction with eigenvalue = e

hbar=1.054571596;				%Planck's constant (x10^34 J s)
hbar2=hbar^2;
echarge=1.602176462;			%electron charge (x10^19 C)
baremass=9.10938188;            %bare electron mass (x10^31 kg)

const=hbar2/baremass/echarge;	%(hbar^2)/(echarge*1nm^2*m0)
const=const/mass;				%/m-effective
deltax=length/n;				%x-increment = length(nm)/n
deltax2=deltax^2;
const=const/deltax2;
%e=zeros(1,end_num_sol);
A=zeros(n,n);

for i=1:n
   d(i)=v(i)+const;				%diagonal matrix element				
   offd(i)=-const/2;			%off-diagonal matrix element
end

t1=offd(1:n-1);							
Hmatrix=diag(t1,1);				%upper diagonal of Hamiltonian matrix							
Hmatrix=Hmatrix+diag(t1,-1);	%add lower diagonal of Hamiltonian matrix

t2=d(1:n);
Hmatrix=Hmatrix+diag(t2,0);		%add diagonal of Hamiltonian matrix

A(1,n)=-const/2;				%periodic boundary conditions
A(n,1)=-const/2;				%periodic boundary conditions

Hmatrix=Hmatrix+A;

%use matlab function eigs to find num_sol eigenfunctions and eigenvalues
%[phi,te]=eigs(Hmatrix,end_num_sol,'SM');
[phi,te]=eigs(Hmatrix,end_num_sol,0);
for i=1:end_num_sol
  e(end_num_sol+1-i)=te(i,i);	%return ordered energy eigenvalues in vector e
end
return

